@@ -11,7 +11,7 @@ def check_request_token(func):
         auth_token = confirm_token()
         if type(auth_token) == str:
             return jsonify(message='Token is invalid', code=403), 403
-        g.user = auth_token.get('user')
+        # g.user = auth_token.get('user')
         return func(*args, **kwargs)
 
     return decorated
