@@ -59,7 +59,7 @@ class RouteBuilder(Blueprint):
         self.delete_flag = flag
 
     def _payload(self):
-        payload = json.loads(request.data)
+        payload = request.json
         return payload
 
     def json(self, data):
